@@ -67,13 +67,10 @@ sub convert_n_test {
     if (Pod::Simple->VERSION > 3.28) {
         $expect =~ s/\n\n(some html)/$1/m;
         $expect =~ s{(TESTING FOR AND BEGIN</h1>)\n\n}{$1}m;
-        $expect =~ s{(intermediate text</p>)\n\n}{$1}m;
-    } else {
-        $expect =~ s/\n\n(some text)/$1/m;
     }
 
 	# result
-	open my $in, $outfile or die "cannot open $outfile: $!";
+	open my $in, '<', $outfile or die "cannot open $outfile: $!";
 	$result = <$in>;
 	close $in;
     }
@@ -91,7 +88,7 @@ sub convert_n_test {
 	  open my $tmpfile, ">", $expectfile or die $!;
 	  print $tmpfile $expect;
 	  close $tmpfile;
-	  open my $diff_fh, "$diff $diffopt $expectfile $outfile |" or die $!;
+	  open my $diff_fh, "-|", "$diff $diffopt $expectfile $outfile" or die $!;
 	  print STDERR "# $_" while <$diff_fh>;
 	  close $diff_fh;
 	  unlink $expectfile;
